@@ -5,7 +5,7 @@ import os
 
 
 def convert(source_path, target_path):
-    from pm4pydistr.util.parquet_exporter import exporter as parquet_exporter
+    from pm4pymdl.util.parquet_exporter import exporter as parquet_exporter
     limit_length = 35
     codec_options = bson.CodecOptions(unicode_decode_error_handler='ignore')
     gen = bson.decode_file_iter(open(source_path, 'rb'), codec_options=codec_options)
